# Changelog

<!--next-version-placeholder-->

## v1.3.0 (2023-01-06)
### Feature
* Token clf wrapper passes tests ([`d8519a3`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/d8519a39217e6dfb1f157806719d4221b99a34d2))
* Test for seq clf tranformer pass ([`5e6bd7e`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/5e6bd7e1a0b32f09b00b6053573db1d196cd95a0))

### Fix
* Added missing import to __init__ ([`abbc025`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/abbc0256a0ca4220fbd56eb3014cf0041c1d3091))
* Handle case for empty strings isn't handled as intended ([`77e7e50`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/77e7e50218910a0d046f59a7063f38ebadfeff8d))
* Handle case for empty strings isn't handled as intended ([`7955f30`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/7955f303e41808c21fa167158ff71519cf003b3b))

### Documentation
* Updated docs with new setup ([`6ed78d6`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/6ed78d6fbb73da4441ff051ac9533ab7bbc42017))
* Updated docs ([`0b2287b`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/0b2287b87c29438434ac5382019cf6e38b68adaa))
* Added new changes to docs ([`9c37520`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/9c37520c95a7983dba9f819fa3c82022e1d47016))
* Updated changelog ([`688e0ec`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/688e0ece6dd2c318837e9342e48b81001dfec8ac))
* Added edit button to docs ([`8e0748e`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/8e0748ea93b802297845380eebeaf2653656d31a))
* Updated citation in documentation ([`e752647`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/e75264777a6f2eafb553d6655a349cd96f8c49a0))
* Added edit button to documentation ([`baf629b`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/baf629b7bb953f65561a092174e492824e87a590))
* Added citation.cff ([`2b07503`](https://github.com/KennethEnevoldsen/spacy-wrap/commit/2b075039272307f6ae99e423c8a44b3572c80e63))
